pub enum SequenceDecoderOutput {
Text(String),
Held,
Stopped,
StoppedWithText(String),
}Expand description
The output conditions/values of a SequenceDecoder::add_token_id operation. Result of decoding a token, indicating whether text was produced or a stop condition was met
Variants
Text(String)
The text for the appended token_id
Held
A sequence of token_ids has been partially matched a stop sequence, so the text is held until either a match or a divergence
Stopped
Indicates that a stop sequence has been matched and the decoder is stopped. Subsequent calls to append_token_id will return an error
StoppedWithText(String)
Indicates that a stop token_id has been matched and the decoder is stopped. Subsequent calls to append_token_id will return an error The text for the stop token_id is returned