pub struct StopSequenceDecoderBuilder { /* private fields */ }Implementations
Sourceimpl StopSequenceDecoderBuilder
impl StopSequenceDecoderBuilder
pub fn new(tokenizer: Tokenizer) -> Self
Sourcepub fn add_stop_token_id_visible(self, token_id: TokenIdType) -> Self
pub fn add_stop_token_id_visible(self, token_id: TokenIdType) -> Self
Adds a visible stop token id to the StopSequenceDecoder
Sourcepub fn add_stop_token_ids_visible(self, token_ids: &[TokenIdType]) -> Self
pub fn add_stop_token_ids_visible(self, token_ids: &[TokenIdType]) -> Self
Adds a list of visible stop token ids to the StopSequenceDecoder Each token_id is added as for an individual match
Adds a hidden stop token id to the StopSequenceDecoder
Adds a list of hidden stop token ids to the StopSequenceDecoder Each token_id is added as for an individual match
pub fn add_stop_sequence_visible(self, text: &str) -> Self
pub fn add_stop_sequences_visible(self, strings: &[&str]) -> Self
pub fn build(self) -> Result<StopSequenceDecoder>